#!/usr/bin/env python3

from druid import crowlib


def main():
    try:
        crow = crowlib.connect()
    except ValueError as err:
        print(err)
        exit()

    crow.write(bytes('^^p', 'utf-8'))
    print(crow.read(1000000).decode())

    crow.close()
    exit()

main()



#!/usr/bin/env python3

import sys
import time

from druid import crowlib


def myprint(st):
    print(st)

def main():
    try:
        crow = crowlib.connect()
    except ValueError as err:
        print(err)
        exit()

    # run script passed from command line
    if len(sys.argv) == 2:
        crowlib.upload(crow.write, myprint, sys.argv[1])
        print(crow.read(1000000).decode())
        print(' file uploaded:')
        time.sleep(0.5)  # wait for new script to be ready
        crow.write(bytes('^^p', 'utf-8'))
        print(crow.read(1000000).decode())
    else:
        print('usage: python3 upload.py file-to-upload.lua')

    crow.close()
    exit()

main()



#!/usr/bin/env python3

from setuptools import setup, find_namespace_packages

setup(
    name="monome-druid",
    version="0.1.0",
    description="Terminal interface for crow",
    url="https://github.com/monome/druid",
    author="monome",
    author_email="bcrabtree@monome.org",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    packages=find_namespace_packages("src"),
    package_dir={"": "src"},
    include_package_data=True,
    python_requires=">=3.5",
    install_requires=[
        "prompt-toolkit>=2.0.10",
        "pyserial>=3.4",
    ],
    extras_require={
        "test": [
            "pylint",
        ]
    },
    entry_points={
        "console_scripts": [
            "druid=druid.main:main",
        ],
    },
)
